# Generated by Django 3.2.13 on 2022-06-22 15:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0025_schoolteacherinvitation"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="teacher",
            name="pending_join_request",
        ),
        migrations.AlterField(
            model_name="teacher",
            name="blocked_time",
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
