# Generated by Django 3.2.15 on 2022-10-12 12:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0028_coding_club_downloads"),
    ]

    operations = [
        migrations.CreateModel(
            name="DynamicElement",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.CharField(max_length=64, unique=True, editable=False)),
                ("active", models.BooleanField(default=False)),
                ("text", models.TextField(blank=True, null=True)),
            ],
        ),
    ]
