# Generated by Django 3.2.16 on 2022-11-22 16:42

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0030_add_maintenance_banner"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dailyactivity",
            options={"verbose_name_plural": "Daily activities"},
        ),
        migrations.AlterField(
            model_name="student",
            name="blocked_time",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="student",
            name="class_field",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="students",
                to="common.class",
            ),
        ),
        migrations.AlterField(
            model_name="student",
            name="pending_class_request",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="class_request",
                to="common.class",
            ),
        ),
        migrations.AlterField(
            model_name="teacher",
            name="school",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="teacher_school",
                to="common.school",
            ),
        ),
    ]
